@@ -1,7 +1,7 @@
 #' Cultural Importance index (CI)
 #'
 #' This function allows you to calculate the Cultural Importance Index (CI) per species.
-#' @source Tardío, J., and M. Pardo-de-Santayana, 2008. Cultural Importance Indices: A Comparative Analysis Based on the Useful Wild Plants of Southern Cantabria (Northern Spain) 1. Economic Botany, 62(1), 24-39. <https://doi.org/10.1007/s12231-007-9004-5>
+#' @source Tardio, J., and M. Pardo-de-Santayana, 2008. Cultural Importance Indices: A Comparative Analysis Based on the Useful Wild Plants of Southern Cantabria (Northern Spain) 1. Economic Botany, 62(1), 24-39. <https://doi.org/10.1007/s12231-007-9004-5>
 #' @param data is an ethnobotany data set with column 1 'informant' and 2 'sp_name' as row identifiers of informants and of species names respectively.
 #' The rest of the columns are the identified ethnobotany use categories. The data should be populated with counts of uses per person (should be 0 or 1 values).
 #' @keywords quantitative ethnobotany cultural importance
@@ -42,12 +42,13 @@ CIs <- function(data) {
   assertthat::see_if(length(data_complete) == length(data), msg = "Some of your observations included \"NA\" and were removed. Consider using \"0\" instead.")
   
   URdata<- data #create subset-able data
+  
   URdata$URps <- dplyr::select(URdata, -informant, -sp_name) %>% rowSums()
     data_URs <- plyr::ddply(URdata, ~sp_name,
                 plyr::summarise, URs = sum(URps))
     data_Ci <- data_URs
     data_Ci$Ci <- data_URs$URs/(length(unique(URdata$informant)) *
-        ncol(URdata[, -c(1:2)]))
+        ncol(dplyr::select(URdata, -informant, -sp_name)))
     
     #change sort order
     CIs<-data_Ci[c(1, 3)]
